@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008, Nokia
+ * Copyright (C) 2008, Nokia <ivan.frade@nokia.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -71,6 +71,10 @@
 #include <libedataserver/e-account.h>
 #include <libedataserver/e-account-list.h>
 
+#ifdef HAVE_EDS_2_29_1
+#include <e-util/e-account-utils.h>
+#endif
+
 #include <libtracker-client/tracker.h>
 #include <libtracker-client/tracker-sparql-builder.h>
 
@@ -2284,7 +2288,11 @@ tracker_evolution_plugin_init (TrackerEvolutionPlugin *plugin)
 	                         G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING,
 	                         G_TYPE_INVALID);
 
+#ifdef HAVE_EDS_2_29_1
+	priv->accounts = g_object_ref (e_get_account_list ());
+#else
 	priv->accounts = g_object_ref (mail_config_get_accounts ());
+#endif
 
 	for (it = e_list_get_iterator (E_LIST (priv->accounts)); e_iterator_is_valid (it); e_iterator_next (it)) {
 		register_account (plugin, (EAccount *) e_iterator_get (it));
