@@ -75,16 +75,11 @@ long long int llroundl(long double x);
 #define GST_TAG_FRAMERATE "framerate"
 #endif
 
-#ifndef GST_TAG_DEVICE_MODEL
-#define GST_TAG_DEVICE_MODEL "device-model"
-#endif
-
-
 typedef enum {
 	EXTRACT_MIME_AUDIO,
 	EXTRACT_MIME_VIDEO,
 	EXTRACT_MIME_IMAGE,
-	EXTRACT_MIME_GUESS,
+	EXTRACT_MIME_3GPP,
 } ExtractMime;
 
 typedef struct {
@@ -129,7 +124,7 @@ static void extract_gstreamer_video (const gchar          *uri,
 static void extract_gstreamer_image (const gchar          *uri,
                                      TrackerSparqlBuilder *preupdate,
                                      TrackerSparqlBuilder *metadata);
-static void extract_gstreamer_guess (const gchar          *uri,
+static void extract_gstreamer_3gpp  (const gchar          *uri,
                                      TrackerSparqlBuilder *preupdate,
                                      TrackerSparqlBuilder *metadata);
 
@@ -137,10 +132,8 @@ static TrackerExtractData data[] = {
 	{ "audio/*", extract_gstreamer_audio },
 	{ "video/*", extract_gstreamer_video },
 	{ "image/*", extract_gstreamer_image },
-	/* Tell gstreamer to guess if mimetype guessing returns video also for audio files */
-	{ "video/3gpp", extract_gstreamer_guess },
-	{ "video/mp4", extract_gstreamer_guess },
-	{ "video/x-ms-asf", extract_gstreamer_guess },
+	/* mime type guessing returns video/3gpp also for 3gpp audio files */
+	{ "video/3gpp", extract_gstreamer_3gpp },
 	{ NULL, NULL }
 };
 
@@ -331,32 +324,6 @@ add_time_gst_tag (TrackerSparqlBuilder   *metadata,
 	}
 }
 
-static void
-add_keywords_gst_tag (TrackerSparqlBuilder *metadata,
-                      GstTagList           *tag_list)
-{
-	gboolean ret;
-	gchar *str;
-
-	ret = gst_tag_list_get_string (tag_list, GST_TAG_KEYWORDS, &str);
-
-	if (ret) {
-		GStrv keywords;
-		gint i = 0;
-
-		keywords = g_strsplit_set (str, " ,", -1);
-
-		while (keywords[i]) {
-			tracker_sparql_builder_predicate (metadata, "nie:keyword");
-			tracker_sparql_builder_object_unvalidated (metadata, g_strstrip (keywords[i]));
-			i++;
-		}
-
-		g_strfreev (keywords);
-		g_free (str);
-	}
-}
-
 static gboolean
 get_embedded_album_art(MetadataExtractor *extractor)
 {
@@ -402,15 +369,18 @@ get_embedded_album_art(MetadataExtractor *extractor)
 
 	if (value) {
 		GstBuffer    *buffer;
+		GstCaps      *caps;
 		GstStructure *caps_struct;
 
 		buffer = gst_value_get_buffer (value);
+		caps   = gst_buffer_get_caps (buffer);
 		caps_struct = gst_caps_get_structure (buffer->caps, 0);
 
 		extractor->album_art_data = buffer->data;
 		extractor->album_art_size = buffer->size;
 		extractor->album_art_mime = gst_structure_get_name (caps_struct);
 
+		gst_object_unref (caps);
 
 		return TRUE;
 	}
@@ -492,6 +462,7 @@ extract_metadata (MetadataExtractor      *extractor,
                   gchar                 **album,
                   gchar                 **scount)
 {
+	const gchar *temp;
 	gchar *s;
 	gboolean ret;
 	gint count;
@@ -501,12 +472,11 @@ extract_metadata (MetadataExtractor      *extractor,
 	g_return_if_fail (metadata != NULL);
 
 	if (extractor->tagcache) {
-		gchar *artist_uri = NULL;
 		gchar *performer_uri = NULL;
 		gchar *composer_uri = NULL;
 		gchar *album_uri = NULL;
 
-		if (extractor->mime == EXTRACT_MIME_GUESS) {
+		if (extractor->mime == EXTRACT_MIME_3GPP) {
 			gchar *video_codec = NULL, *audio_codec = NULL;
 
 			gst_tag_list_get_string (extractor->tagcache, GST_TAG_VIDEO_CODEC, &video_codec);
@@ -530,34 +500,25 @@ extract_metadata (MetadataExtractor      *extractor,
 			gst_tag_list_get_string (extractor->tagcache, GST_TAG_PERFORMER, &performer);
 			gst_tag_list_get_string (extractor->tagcache, GST_TAG_ARTIST, &artist_local);
 
-			if (artist_local) {
-				artist_uri = tracker_uri_printf_escaped ("urn:artist:%s", artist_local);
+			temp = tracker_coalesce_strip (2, performer, artist_local);
 
-				tracker_sparql_builder_insert_open (preupdate, NULL);
-				tracker_sparql_builder_subject_iri (preupdate, artist_uri);
-				tracker_sparql_builder_predicate (preupdate, "a");
-				tracker_sparql_builder_object (preupdate, "nmm:Artist");
-				tracker_sparql_builder_predicate (preupdate, "nmm:artistName");
-				tracker_sparql_builder_object_unvalidated (preupdate, artist_local);
-				tracker_sparql_builder_insert_close (preupdate);
-			}
-
-			s = tracker_coalesce (2, performer, artist_local);
-
-			if (s) {
-				performer_uri = tracker_uri_printf_escaped ("urn:artist:%s", s);
+			if (temp) {
+				performer_uri = tracker_uri_printf_escaped ("urn:artist:%s", temp);
 
 				tracker_sparql_builder_insert_open (preupdate, NULL);
 				tracker_sparql_builder_subject_iri (preupdate, performer_uri);
 				tracker_sparql_builder_predicate (preupdate, "a");
 				tracker_sparql_builder_object (preupdate, "nmm:Artist");
 				tracker_sparql_builder_predicate (preupdate, "nmm:artistName");
-				tracker_sparql_builder_object_unvalidated (preupdate, s);
+				tracker_sparql_builder_object_unvalidated (preupdate, temp);
 				tracker_sparql_builder_insert_close (preupdate);
 
-				*artist = s;
+				*artist = g_strdup (temp);
 			}
 
+			g_free (performer);
+			g_free (artist_local);
+
 			s = NULL;
 			gst_tag_list_get_string (extractor->tagcache, GST_TAG_COMPOSER, &s);
 
@@ -582,11 +543,7 @@ extract_metadata (MetadataExtractor      *extractor,
 
 		/* Audio */
 		s = NULL;
-
-		if (extractor->mime == EXTRACT_MIME_AUDIO) {
-			gst_tag_list_get_string (extractor->tagcache, GST_TAG_ALBUM, &s);
-		}
-
+		gst_tag_list_get_string (extractor->tagcache, GST_TAG_ALBUM, &s);
 		if (s) {
 			gboolean has_it;
 			guint count;
@@ -604,15 +561,10 @@ extract_metadata (MetadataExtractor      *extractor,
 			tracker_sparql_builder_predicate (preupdate, "nmm:albumTitle");
 			tracker_sparql_builder_object_unvalidated (preupdate, s);
 
-			if (artist_uri) {
-				tracker_sparql_builder_predicate (preupdate, "nmm:albumArtist");
-				tracker_sparql_builder_object_iri (preupdate, artist_uri);
-			}
-
 			tracker_sparql_builder_insert_close (preupdate);
 
-			has_it = gst_tag_list_get_uint (extractor->tagcache,
-			                                GST_TAG_TRACK_COUNT,
+			has_it = gst_tag_list_get_uint (extractor->tagcache, 
+			                                GST_TAG_TRACK_COUNT, 
 			                                &count);
 
 			if (has_it) {
@@ -637,8 +589,8 @@ extract_metadata (MetadataExtractor      *extractor,
 				tracker_sparql_builder_insert_close (preupdate);
 			}
 
-			has_it = gst_tag_list_get_uint (extractor->tagcache,
-			                                GST_TAG_ALBUM_VOLUME_NUMBER,
+			has_it = gst_tag_list_get_uint (extractor->tagcache, 
+			                                GST_TAG_ALBUM_VOLUME_NUMBER, 
 			                                &count);
 
 			if (has_it) {
@@ -663,8 +615,8 @@ extract_metadata (MetadataExtractor      *extractor,
 				tracker_sparql_builder_insert_close (preupdate);
 			}
 
-			has_it = gst_tag_list_get_double (extractor->tagcache,
-			                                  GST_TAG_ALBUM_GAIN,
+			has_it = gst_tag_list_get_double (extractor->tagcache, 
+			                                  GST_TAG_ALBUM_GAIN, 
 			                                  &gain);
 
 			if (has_it) {
@@ -689,8 +641,8 @@ extract_metadata (MetadataExtractor      *extractor,
 				tracker_sparql_builder_insert_close (preupdate);
 			}
 
-			has_it = gst_tag_list_get_double (extractor->tagcache,
-			                                  GST_TAG_ALBUM_PEAK,
+			has_it = gst_tag_list_get_double (extractor->tagcache, 
+			                                  GST_TAG_ALBUM_PEAK, 
 			                                  &gain);
 
 			if (has_it) {
@@ -727,7 +679,7 @@ extract_metadata (MetadataExtractor      *extractor,
 		if (needs_audio) {
 			tracker_sparql_builder_object (metadata, "nmm:MusicPiece");
 			tracker_sparql_builder_object (metadata, "nfo:Audio");
-		}
+		} 
 
 		if (extractor->mime == EXTRACT_MIME_VIDEO) {
 			tracker_sparql_builder_object (metadata, "nmm:Video");
@@ -749,7 +701,6 @@ extract_metadata (MetadataExtractor      *extractor,
 		add_string_gst_tag (metadata, uri, "dc:coverage", extractor->tagcache, GST_TAG_LOCATION);
 		add_y_date_gst_tag (metadata, uri, "nie:contentCreated", extractor->tagcache, GST_TAG_DATE);
 		add_string_gst_tag (metadata, uri, "nie:comment", extractor->tagcache, GST_TAG_COMMENT);
-		add_string_gst_tag (metadata, uri, "nfo:device", extractor->tagcache, GST_TAG_DEVICE_MODEL);
 
 		if (extractor->is_content_encrypted) {
 			tracker_sparql_builder_predicate (metadata, "nfo:isContentEncrypted");
@@ -768,8 +719,6 @@ extract_metadata (MetadataExtractor      *extractor,
 				tracker_sparql_builder_predicate (metadata, "nmm:director");
 				tracker_sparql_builder_object_iri (metadata, composer_uri);
 			}
-
-			add_keywords_gst_tag (metadata, extractor->tagcache);
 		}
 
 		if (needs_audio) {
@@ -801,7 +750,6 @@ extract_metadata (MetadataExtractor      *extractor,
 		}
 
 		g_free (performer_uri);
-		g_free (artist_uri);
 		g_free (composer_uri);
 		g_free (album_uri);
 
@@ -815,7 +763,7 @@ extract_metadata (MetadataExtractor      *extractor,
 		if (needs_audio) {
 			tracker_sparql_builder_object (metadata, "nmm:MusicPiece");
 			tracker_sparql_builder_object (metadata, "nfo:Audio");
-		}
+		} 
 
 		if (extractor->mime == EXTRACT_MIME_VIDEO) {
 			tracker_sparql_builder_object (metadata, "nmm:Video");
@@ -1069,39 +1017,37 @@ create_decodebin_pipeline (MetadataExtractor *extractor, const gchar *uri)
 	GstElement *filesrc  = NULL;
 	GstElement *bin      = NULL;
 
+	guint       id;
+
 	pipeline = gst_element_factory_make ("pipeline", NULL);
 	if (!pipeline) {
 		g_warning ("Failed to create GStreamer pipeline");
-		return NULL;
+		return FALSE;
 	}
 
 	filesrc = gst_element_factory_make ("giosrc", NULL);
 	if (!filesrc) {
 		g_warning ("Failed to create GStreamer giosrc");
-		gst_object_unref (GST_OBJECT (pipeline));
-		return NULL;
+		return FALSE;
 	}
 
 	bin = gst_element_factory_make ("decodebin2", "decodebin2");
 	if (!bin) {
 		g_warning ("Failed to create GStreamer decodebin");
-		gst_object_unref (GST_OBJECT (pipeline));
-		gst_object_unref (GST_OBJECT (filesrc));
-		return NULL;
+		return FALSE;
 	}
 
-	g_signal_connect (G_OBJECT (bin),
-			  "new-decoded-pad",
-			  G_CALLBACK (dbin_dpad_cb),
-			  extractor);
+	id = g_signal_connect (G_OBJECT (bin),
+	                       "new-decoded-pad",
+	                       G_CALLBACK (dbin_dpad_cb),
+	                       extractor);
 
 	gst_bin_add (GST_BIN (pipeline), filesrc);
 	gst_bin_add (GST_BIN (pipeline), bin);
 
 	if (!gst_element_link_many (filesrc, bin, NULL)) {
 		g_warning ("Could not link GStreamer elements");
-		gst_object_unref (GST_OBJECT (pipeline));
-		return NULL;
+		return FALSE;
 	}
 
 	g_object_set (G_OBJECT (filesrc), "location", uri, NULL);
@@ -1174,7 +1120,6 @@ tracker_extract_gstreamer (const gchar *uri,
 
 	if (!extractor->pipeline) {
 		g_warning ("No valid pipeline for uri %s", uri);
-		g_slice_free (MetadataExtractor, extractor);
 		return;
 	}
 
@@ -1183,19 +1128,11 @@ tracker_extract_gstreamer (const gchar *uri,
 	if (use_tagreadbin) {
 		if (!poll_for_ready (extractor, GST_STATE_PLAYING, FALSE, TRUE)) {
 			g_warning ("Error running tagreadbin");
-			gst_element_set_state (extractor->pipeline, GST_STATE_NULL);
-			gst_object_unref (GST_OBJECT (extractor->pipeline));
-			gst_object_unref (extractor->bus);
-			g_slice_free (MetadataExtractor, extractor);
 			return;
 		}
 	} else {
 		if (!poll_for_ready (extractor, GST_STATE_PAUSED, TRUE, FALSE)) {
 			g_warning ("Error running decodebin");
-			gst_element_set_state (extractor->pipeline, GST_STATE_NULL);
-			gst_object_unref (GST_OBJECT (extractor->pipeline));
-			gst_object_unref (extractor->bus);
-			g_slice_free (MetadataExtractor, extractor);
 			return;
 		}
 
@@ -1262,11 +1199,11 @@ extract_gstreamer_image (const gchar          *uri,
 }
 
 static void
-extract_gstreamer_guess (const gchar          *uri,
+extract_gstreamer_3gpp (const gchar          *uri,
                         TrackerSparqlBuilder *preupdate,
 			TrackerSparqlBuilder *metadata)
 {
-	tracker_extract_gstreamer (uri, preupdate, metadata, EXTRACT_MIME_GUESS);
+	tracker_extract_gstreamer (uri, preupdate, metadata, EXTRACT_MIME_3GPP);
 }
 
 TrackerExtractData *
